package com.xinda.itsm.mapper;

import java.util.List;
import com.xinda.itsm.domain.InspectionRecord;

/**
 * 巡检记录Mapper接口
 *
 * @author kerwincui
 * @date 2025-04-23
 */
public interface InspectionRecordMapper
{
    /**
     * 查询巡检记录
     *
     * @param id 巡检记录主键
     * @return 巡检记录
     */
    public InspectionRecord selectInspectionRecordById(Long id);

    /**
     * 查询巡检记录列表
     *
     * @param inspectionRecord 巡检记录
     * @return 巡检记录集合
     */
    public List<InspectionRecord> selectInspectionRecordList(InspectionRecord inspectionRecord);

    /**
     * 新增巡检记录
     *
     * @param inspectionRecord 巡检记录
     * @return 结果
     */
    public int insertInspectionRecord(InspectionRecord inspectionRecord);

    /**
     * 修改巡检记录
     *
     * @param inspectionRecord 巡检记录
     * @return 结果
     */
    public int updateInspectionRecord(InspectionRecord inspectionRecord);

    /**
     * 删除巡检记录
     *
     * @param id 巡检记录主键
     * @return 结果
     */
    public int deleteInspectionRecordById(Long id);

    /**
     * 批量删除巡检记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInspectionRecordByIds(Long[] ids);
}
